---
name: Bug report
about: Create a report to help us improve
title: "[ short, descriptive title ]"
labels: bug
assignees: Pencilcaseman

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Create a thing
2. Do the thing to the other thing
3. Then do that thing
4. Then maybe do another thing?

**Minimal Reproducable Example**
(see [StackOverflow's answer](https://stackoverflow.com/help/minimal-reproducible-example))
```cpp
#include <librapid>

int main() {
    fmt::print("Hello, World\n");
    return 0;
}
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Stack Traces**
If applicable, add *relevant* stack trace information to help solve the problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Widnows]
 - Compiler: [e.g. MSVC]
 - C++ Version: [e.g. C++17]

**Additional context**
Add any other context about the problem here.
